# Topsis Calculator
It takes 4 inputs namely input file, weight vector, impact vector, output file



## Installation
```pip install topsis-agrim-102003549```

## License
© 2023 Agrim Sood

This repository iss licensed under MIT License.
See License for details.